bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.delete
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.delete